@@ -16,7 +16,10 @@ package ui
 
 import (
 	// The blank import is to make Go modules happy.
+	_ "github.com/shurcooL/httpfs/filter"
+	_ "github.com/shurcooL/httpfs/union"
 	_ "github.com/shurcooL/vfsgen"
 )
 
-//go:generate go run -mod=vendor -tags=dev assets_generate.go
+// NOTE(spasquie): using ondiskassets tag becaues Go 1.12 doesn't support comma-separated tags.
+//go:generate go run -mod=vendor -tags=ondiskassets assets_generate.go
